References
==========

.. [1] Parsons J, Holmes JB, Rojas JM, Tsai J, Strauss CE (2005).
    Practical conversion from torsion space to Cartesian space for in silico protein synthesis.
    J Comput Chem. 26(10), 1063-8.
    `doi:10.1002/jcc.20237 <http://dx.doi.org/10.1002/jcc.20237>`_
.. [2] L. M. Mentel (2014). mendeleev, Available at: https://bitbucket.org/lukaszmentel/mendeleev
.. [3]  Goran Kovacevic, Veryazov, Valera (2015).
    Luscus: molecular viewer and editor for MOLCAS.
    Journal of Cheminformatics. 7(1), 1-10
    `doi:10.1186/s13321-015-0060-z <http://dx.doi.org/10.1186/s13321-015-0060-z>`_
.. [4] Kabsch W. (1976).
    A solution for the best rotation to relate two sets of vectors.
    Acta Crystallographica, A32:922-923.
    `doi:10.1107/S0567739476001873 <http://dx.doi.org/10.1107/S0567739476001873>`_
.. [5] Jimmy Charnley Kromann ; Casper Steinmann ; larsbratholm ; aandi ; Kasper Primdal Lauritzen (2016).
    GitHub: Calculate RMSD for two XYZ structures.
    http://github.com/charnley/rmsd, `doi:10.5281/zenodo.46697 <http://dx.doi.org/10.5281/zenodo.46697>`_
.. [6] Gerald R. Kneller (2005).
    Eckart axis conditions, Gauss’ principle of least constraint, and the optimal superposition of molecular structures
    The Journal of Chemical Physics 128(19), 194101.
    `doi:10.1063/1.2902290 <https://aip.scitation.org/doi/10.1063/1.2902290>`_
